#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Find trends using 2 custom inputs (slow and fast periods)
    /// </summary>
    [Description("Find trends using 2 custom inputs (slow and fast periods)")]
    public class HPTTrendFinder : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int slow = 60; // Default setting for Slow
            private int fast = 30; // Default setting for Fast
			private int reversalbar= 7; //Default setting for reversal bar
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
			PaintPriceMarkers = true; // Indicator plot values are displayed in the y axis 
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (slow<fast)
				return;
			if (fast<reversalbar)
				return;
           	if (CurrentBar < slow + 1)
                     return;
			{
				//Buy Signal
				if (High[0] > MAX(High,slow)[slow] && High[0] > MAX(High,fast)[fast] && 
					Low[0]< MIN(Low,reversalbar)[reversalbar] && Close[0] > High[1])
    			DrawArrowUp("TrendFinder Buy" + CurrentBar.ToString(), true, 0, Low[0]-TickSize, Color.Blue);				
			}
			{
				//Sell signal
				if (Low[0] < MAX(Low,slow)[slow] && Low[0] < MAX(Low,fast)[fast] 
					&& High[0] > MAX(High,reversalbar)[reversalbar] && Close[0]<Low[1])
    			DrawArrowDown("Trendfiner Sell" + CurrentBar.ToString(), true, 0, High[0]+TickSize, Color.Red);
			}
        }

        #region Properties

        [Description("")]
        [Category("Parameters")]
        public int Slow
        {
            get { return slow; }
            set { slow = Math.Max(1, value); }
        }

        [Description("")]
        [Category("Parameters")]
        public int Fast
        {
            get { return fast; }
            set { fast = Math.Max(1, value); }
        }
		[Description("")]
        [Category("Parameters")]
        public int Reversalbar
        {
            get { return reversalbar; }
            set { reversalbar = Math.Max(1, value); }
        }		
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private HPTTrendFinder[] cacheHPTTrendFinder = null;

        private static HPTTrendFinder checkHPTTrendFinder = new HPTTrendFinder();

        /// <summary>
        /// Find trends using 2 custom inputs (slow and fast periods)
        /// </summary>
        /// <returns></returns>
        public HPTTrendFinder HPTTrendFinder(int fast, int reversalbar, int slow)
        {
            return HPTTrendFinder(Input, fast, reversalbar, slow);
        }

        /// <summary>
        /// Find trends using 2 custom inputs (slow and fast periods)
        /// </summary>
        /// <returns></returns>
        public HPTTrendFinder HPTTrendFinder(Data.IDataSeries input, int fast, int reversalbar, int slow)
        {
            checkHPTTrendFinder.Fast = fast;
            fast = checkHPTTrendFinder.Fast;
            checkHPTTrendFinder.Reversalbar = reversalbar;
            reversalbar = checkHPTTrendFinder.Reversalbar;
            checkHPTTrendFinder.Slow = slow;
            slow = checkHPTTrendFinder.Slow;

            if (cacheHPTTrendFinder != null)
                for (int idx = 0; idx < cacheHPTTrendFinder.Length; idx++)
                    if (cacheHPTTrendFinder[idx].Fast == fast && cacheHPTTrendFinder[idx].Reversalbar == reversalbar && cacheHPTTrendFinder[idx].Slow == slow && cacheHPTTrendFinder[idx].EqualsInput(input))
                        return cacheHPTTrendFinder[idx];

            HPTTrendFinder indicator = new HPTTrendFinder();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Fast = fast;
            indicator.Reversalbar = reversalbar;
            indicator.Slow = slow;
            indicator.SetUp();

            HPTTrendFinder[] tmp = new HPTTrendFinder[cacheHPTTrendFinder == null ? 1 : cacheHPTTrendFinder.Length + 1];
            if (cacheHPTTrendFinder != null)
                cacheHPTTrendFinder.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheHPTTrendFinder = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Find trends using 2 custom inputs (slow and fast periods)
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.HPTTrendFinder HPTTrendFinder(int fast, int reversalbar, int slow)
        {
            return _indicator.HPTTrendFinder(Input, fast, reversalbar, slow);
        }

        /// <summary>
        /// Find trends using 2 custom inputs (slow and fast periods)
        /// </summary>
        /// <returns></returns>
        public Indicator.HPTTrendFinder HPTTrendFinder(Data.IDataSeries input, int fast, int reversalbar, int slow)
        {
            return _indicator.HPTTrendFinder(input, fast, reversalbar, slow);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Find trends using 2 custom inputs (slow and fast periods)
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.HPTTrendFinder HPTTrendFinder(int fast, int reversalbar, int slow)
        {
            return _indicator.HPTTrendFinder(Input, fast, reversalbar, slow);
        }

        /// <summary>
        /// Find trends using 2 custom inputs (slow and fast periods)
        /// </summary>
        /// <returns></returns>
        public Indicator.HPTTrendFinder HPTTrendFinder(Data.IDataSeries input, int fast, int reversalbar, int slow)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.HPTTrendFinder(input, fast, reversalbar, slow);
        }

    }
}
#endregion
